{% extends "cjkcms/pages/web_page.html" %}

{% load i18n %}

{% block content_body %}

<div class="container my-5">
    <h2>{% trans 'Thank You' %}</h2>
    <p>{% trans 'We have successfully received your submission.' %}</p>
</div>

{% endblock %}
