{% extends "cjkcms/blocks/grid_block.html" %}
{% load wagtailcore_tags %}

{% block grid_content %}
<div class="row
    {% if self.settings.custom_css_class %}
        {{self.settings.custom_css_class}}
    {% else %}
        row-cols-1 row-cols-md-2 row-cols-lg-3 g-4
    {% endif %} ">
      {% for block in self.content %}
          <div class="col">
            {% include_block block %}
          </div>
      {% endfor %}
</div>
{% endblock %}
