{% load wagtailcore_tags wagtailimages_tags %}

<div class="card mb-3 {{self.settings.custom_css_class}}"
{% if self.settings.custom_id %}id="{{self.settings.custom_id}}"{% endif %}>
    {% if self.title %}<h5 class="card-header">{{self.title}}</h5>{% endif %}
    {% if self.image %}
    {% image self.image fill-900x600 as card_img %}
    <img class="w-100" src="{{card_img.url}}" alt="{{card_img.title}}">
    {% endif %}
    <div class="card-body">
        {% if self.subtitle %}<h6 class="card-subtitle mb-2 text-muted">{{self.subtitle}}</h6>{% endif %}
        <div class="card-text">{{self.description}}</div>
        {% for button in self.links %}
        {% include_block button %}
        {% endfor %}
    </div>
</div>
